local E, L, V, P, G = unpack(ElvUI)
local IsAddOnLoaded = IsAddOnLoaded
local format = string.format
local MyPluginName = "GennUI"
local GNUI = E:GetModule("GennUI");

--[[ Setup Chat ]]--
function GNUI:SetupChat()
	
	FCF_ResetChatWindows()
	FCF_SetLocked(ChatFrame1, 1)
	FCF_DockFrame(ChatFrame1)
	FCF_SetLocked(ChatFrame2, 1)
	FCF_OpenNewWindow(TRADE)
	FCF_SetLocked(ChatFrame3, 1)
	FCF_DockFrame(ChatFrame3)
	
	for i = 1, NUM_CHAT_WINDOWS do
		local frame = _G[format('ChatFrame%s', i)]

		FCF_SavePositionAndDimensions(frame)
		FCF_StopDragging(frame)

		FCF_SetChatWindowFontSize(nil, frame, 12)

		if i == 1 then
			FCF_SetWindowName(frame, GENERAL)
		elseif i == 2 then
			FCF_SetWindowName(frame, GUILD_EVENT_LOG)
		elseif i == 3 then
			FCF_SetWindowName(frame, TRADE)
		end
	end
	
	-- keys taken from `ChatTypeGroup` but doesnt add: 'OPENING', 'TRADESKILLS', 'PET_INFO', 'COMBAT_MISC_INFO', 'COMMUNITIES_CHANNEL', 'PET_BATTLE_COMBAT_LOG', 'PET_BATTLE_INFO', 'TARGETICONS'
	local chatGroup = { 'SYSTEM', 'CHANNEL', 'SAY', 'EMOTE', 'YELL', 'WHISPER', 'PARTY', 'PARTY_LEADER', 'RAID', 'RAID_LEADER', 'RAID_WARNING', 'INSTANCE_CHAT', 'INSTANCE_CHAT_LEADER', 'GUILD', 'OFFICER', 'MONSTER_SAY', 'MONSTER_YELL', 'MONSTER_EMOTE', 'MONSTER_WHISPER', 'MONSTER_BOSS_EMOTE', 'MONSTER_BOSS_WHISPER', 'ERRORS', 'AFK', 'DND', 'IGNORED', 'BG_HORDE', 'BG_ALLIANCE', 'BG_NEUTRAL', 'ACHIEVEMENT', 'GUILD_ACHIEVEMENT', 'BN_WHISPER', 'BN_INLINE_TOAST_ALERT', 'COMBAT_XP_GAIN', 'COMBAT_HONOR_GAIN', 'COMBAT_FACTION_CHANGE', 'SKILL', 'LOOT', 'CURRENCY', 'MONEY' }
	ChatFrame_RemoveAllMessageGroups(_G.ChatFrame1)
	ChatFrame_RemoveAllMessageGroups(_G.ChatFrame3)
	for _, v in ipairs(chatGroup) do
		ChatFrame_AddMessageGroup(_G.ChatFrame1, v)
	end

	ChatFrame_AddChannel(_G.ChatFrame1, GENERAL)
	ChatFrame_RemoveChannel(_G.ChatFrame1, TRADE)
	ChatFrame_AddChannel(_G.ChatFrame3, TRADE)

	-- set the chat groups names in class color to enabled for all chat groups which players names appear
	chatGroup = { 'SAY', 'EMOTE', 'YELL', 'WHISPER', 'PARTY', 'PARTY_LEADER', 'RAID', 'RAID_LEADER', 'RAID_WARNING', 'INSTANCE_CHAT', 'INSTANCE_CHAT_LEADER', 'GUILD', 'OFFICER', 'ACHIEVEMENT', 'GUILD_ACHIEVEMENT', 'COMMUNITIES_CHANNEL', 'CHANNEL1', 'CHANNEL2', 'CHANNEL3', 'CHANNEL4', 'CHANNEL5', 'CHANNEL6', 'CHANNEL7', 'CHANNEL8', 'CHANNEL9', 'CHANNEL10', 'CHANNEL11' }
	for i = 1, _G.MAX_WOW_CHAT_CHANNELS do
		tinsert(chatGroup, 'CHANNEL'..i)
	end
	for _, v in ipairs(chatGroup) do
		ToggleChatColorNamesByClassGroup(true, v)
	end
		
	E:Print(L["Chat has been set"])
	PluginInstallStepComplete.message = "Chat has been set"
	PluginInstallStepComplete:Show()
end

--[[ Class Colors ]]--
local colorTable = class == 'PRIEST' and E.PriestColors or (_G.CUSTOM_CLASS_COLORS and _G.CUSTOM_CLASS_COLORS[class] or _G.RAID_CLASS_COLORS[class])
local classColor = RAID_CLASS_COLORS[E.myclass]

--[[ Layout Settings ]]--
function GNUI:SetupLayout(layout)

-- Movers
E.db["movers"] = E.db["movers"] or {}
E.db["movers"]["ThreatBarMover"] = "BOTTOM,ElvUIParent,BOTTOM,3,83"
E.db["movers"]["ElvUF_FocusCastbarMover"] = "TOP,ElvUIParent,TOP,0,-399"
E.db["movers"]["ElvUF_FocusMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-585,-470"
E.db["movers"]["ElvUF_PlayerCastbarMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,388"
E.db["movers"]["ElvUF_RaidMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,118"
E.db["movers"]["BossButton"] = "BOTTOM,ElvUIParent,BOTTOM,260,120"
E.db["movers"]["LootFrameMover"] = "TOPLEFT,ElvUIParent,TOPLEFT,490,-246"
E.db["movers"]["ZoneAbility"] = "BOTTOM,ElvUIParent,BOTTOM,-260,120"
E.db["movers"]["ClassBarMover"] = "BOTTOM,ElvUIParent,BOTTOM,-280,312"
E.db["movers"]["DurabilityFrameMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-586,-318"
E.db["movers"]["VehicleSeatMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-524,-4"
E.db["movers"]["ExperienceBarMover"] = "BOTTOM,ElvUIParent,BOTTOM,3,9"
E.db["movers"]["ElvUF_TargetMover"] = "BOTTOM,ElvUIParent,BOTTOM,280,290"
E.db["movers"]["LossControlMover"] = "BOTTOM,ElvUIParent,BOTTOM,-1,507"
E.db["movers"]["ElvUF_Raid40Mover"] = "BOTTOM,ElvUIParent,BOTTOM,0,90"
E.db["movers"]["ElvAB_1"] = "BOTTOM,ElvUIParent,BOTTOM,0,16"
E.db["movers"]["ElvAB_2"] = "BOTTOM,ElvUIParent,BOTTOM,0,49"
E.db["movers"]["TalkingHeadFrameMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,4,186"
E.db["movers"]["AzeriteBarMover"] = "BOTTOM,ElvUIParent,BOTTOM,-290,4"
E.db["movers"]["ElvAB_3"] = "BOTTOM,ElvUIParent,BOTTOM,291,10"
E.db["movers"]["ReputationBarMover"] = "BOTTOM,ElvUIParent,BOTTOM,3,3"
E.db["movers"]["VehicleLeaveButton"] = "TOP,ElvUIParent,TOP,0,-344"
E.db["movers"]["ElvNP_PlayerMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,320"
E.db["movers"]["BNETMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,4,186"
E.db["movers"]["VOICECHAT"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,4,299"
E.db["movers"]["ArenaHeaderMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-297,368"
E.db["movers"]["HonorBarMover"] = "BOTTOM,ElvUIParent,BOTTOM,290,4"
E.db["movers"]["ElvUF_TargetCastbarMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,407"
E.db["movers"]["TooltipMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-559,-246"
E.db["movers"]["MicrobarMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-321,4"
E.db["movers"]["BossHeaderMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-297,368"
E.db["movers"]["ElvUF_PetMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,585,248"
E.db["movers"]["ElvUF_PlayerMover"] = "BOTTOM,ElvUIParent,BOTTOM,-280,290"
E.db["movers"]["ElvUF_PartyMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,419,368"
E.db["movers"]["ElvAB_5"] = "BOTTOM,ElvUIParent,BOTTOM,-290,10"
E.db["movers"]["ShiftAB"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-315,35"
E.db["movers"]["ElvUF_TargetTargetMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-585,248"
E.db["movers"]["TotemBarMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,418,4"
E.db["movers"]["BelowMinimapContainerMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-232"
E.db["movers"]["AlertFrameMover"] = "TOP,ElvUIParent,TOP,0,-200"
E.db["movers"]["WTGameBarAnchor"] = "TOP,ElvUIParent,TOP,0,-2"

-- DataBars		
E.db["databars"]["threat"]["enable"] = false
E.db["databars"]["threat"]["font"] = "Century Gothic Bold"
E.db["databars"]["threat"]["height"] = 6
E.db["databars"]["threat"]["width"] = 399
E.db["databars"]["experience"]["font"] = "Century Gothic Bold"
E.db["databars"]["experience"]["orientation"] = "HORIZONTAL"
E.db["databars"]["experience"]["height"] = 6
E.db["databars"]["experience"]["fontSize"] = 11
E.db["databars"]["experience"]["width"] = 399
E.db["databars"]["experience"]["hideAtMaxLevel"] = false
E.db["databars"]["colors"]["experience"]["a"] = 0.70
E.db["databars"]["colors"]["experience"]["r"] = classColor.r
E.db["databars"]["colors"]["experience"]["g"] = classColor.g
E.db["databars"]["colors"]["experience"]["b"] = classColor.b
E.db["databars"]["honor"]["font"] = "Century Gothic Bold"
E.db["databars"]["honor"]["orientation"] = "HORIZONTAL"
E.db["databars"]["honor"]["enable"] = false
E.db["databars"]["honor"]["height"] = 6
E.db["databars"]["honor"]["mouseover"] = true
E.db["databars"]["honor"]["width"] = 176
E.db["databars"]["reputation"]["font"] = "Century Gothic Bold"
E.db["databars"]["reputation"]["orientation"] = "HORIZONTAL"
E.db["databars"]["reputation"]["enable"] = true
E.db["databars"]["reputation"]["height"] = 6
E.db["databars"]["reputation"]["mouseover"] = true
E.db["databars"]["reputation"]["width"] = 399
E.db["databars"]["azerite"]["font"] = "Century Gothic Bold"
E.db["databars"]["azerite"]["hideAtMaxLevel"] = false
E.db["databars"]["azerite"]["height"] = 6
E.db["databars"]["azerite"]["orientation"] = "HORIZONTAL"
E.db["databars"]["azerite"]["enable"] = false
E.db["databars"]["azerite"]["mouseover"] = true
E.db["databars"]["azerite"]["width"] = 176

-- Tooltip
E.db["tooltip"]["showMount"] = false
E.db["tooltip"]["cursorAnchor"] = true
E.db["tooltip"]["itemCount"] = "BOTH"
E.db["tooltip"]["font"] = "Century Gothic Bold"
E.db["tooltip"]["role"] = false
E.db["tooltip"]["healthBar"]["statusPosition"] = "TOP"
E.db["tooltip"]["healthBar"]["font"] = "Century Gothic Bold"
E.db["tooltip"]["healthBar"]["fontSize"] = 12
E.db["tooltip"]["healthBar"]["height"] = 2

-- Bags
E.db["bags"]["countFontSize"] = 12
E.db["bags"]["itemLevelFont"] = "Century Gothic Bold"
E.db["bags"]["itemLevelFontSize"] = 12
E.db["bags"]["junkIcon"] = true
E.db["bags"]["countFont"] = "Century Gothic Bold"
E.db["bags"]["itemLevel"] = false
E.db["bags"]["clearSearchOnClose"] = true
E.db["bags"]["bagSize"] = 24
E.db["bags"]["vendorGrays"]["enable"] = true
E.db["bags"]["countFontOutline"] = "OUTLINE"
E.db["bags"]["bankSize"] = 24
E.db["bags"]["bagBar"]["size"] = 24
E.db["bags"]["itemLevelFontOutline"] = "OUTLINE"
E.db["bags"]["moneyCoins"] = false
E.db["bags"]["showBindType"] = true
E.db["bags"]["moneyFormat"] = "BLIZZARD"

-- Chat
E.db["chat"]["font"] = "Century Gothic Bold"
E.db["chat"]["emotionIcons"] = false
E.db["chat"]["fontOutline"] = "OUTLINE"
E.db["chat"]["tabFont"] = "Century Gothic Bold"
E.db["chat"]["fontSize"] = 12
E.db["chat"]["tabFontOutline"] = "OUTLINE"
E.db["chat"]["panelBackdrop"] = "HIDEBOTH"
E.db["chat"]["hideVoiceButtons"] = true
E.db["chat"]["chatHistory"] = false

-- Auras
E.db["auras"]["buffs"]["barColor"]["b"] = classColor.b
E.db["auras"]["buffs"]["barColor"]["g"] = classColor.g
E.db["auras"]["buffs"]["barColor"]["r"] = classColor.r
E.db["auras"]["buffs"]["barTexture"] = "GennUI Melli"
E.db["auras"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["auras"]["buffs"]["countFontOutline"] = "OUTLINE"
E.db["auras"]["buffs"]["countFontSize"] = 12
E.db["auras"]["buffs"]["horizontalSpacing"] = 2
E.db["auras"]["buffs"]["size"] = 28
E.db["auras"]["buffs"]["timeFont"] = "Century Gothic Bold"
E.db["auras"]["buffs"]["timeFontOutline"] = "OUTLINE"
E.db["auras"]["buffs"]["timeFontSize"] = 12
E.db["auras"]["buffs"]["timeYOffset"] = 6
E.db["auras"]["debuffs"]["barColor"]["b"] = classColor.b
E.db["auras"]["debuffs"]["barColor"]["g"] = classColor.g
E.db["auras"]["debuffs"]["barColor"]["r"] = classColor.r
E.db["auras"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["auras"]["debuffs"]["countFontOutline"] = "OUTLINE"
E.db["auras"]["debuffs"]["countFontSize"] = 12
E.db["auras"]["debuffs"]["horizontalSpacing"] = 2
E.db["auras"]["debuffs"]["size"] = 28
E.db["auras"]["debuffs"]["timeFont"] = "Century Gothic Bold"
E.db["auras"]["debuffs"]["timeFontOutline"] = "OUTLINE"
E.db["auras"]["debuffs"]["timeFontSize"] = 12
E.db["auras"]["debuffs"]["timeYOffset"] = 6

-- Unitframes
---> UF Colors & Stuff
E.db["unitframe"]["colors"]["healthclass"] = true
E.db["unitframe"]["colors"]["powerclass"] = false
E.db["unitframe"]["colors"]["classbackdrop"] = false
E.db["unitframe"]["colors"]["colorhealthbyvalue"] = false
E.db["unitframe"]["colors"]["customhealthbackdrop"] = true
E.db["unitframe"]["colors"]["customcastbarbackdrop"] = true
E.db["unitframe"]["colors"]["healthMultiplier"] = 1
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][1]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][1]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][1]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][2]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][2]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][2]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][3]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][3]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][3]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["DEATHKNIGHT"]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["DEATHKNIGHT"]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["DEATHKNIGHT"]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["PALADIN"]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["PALADIN"]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["PALADIN"]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["MAGE"]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["MAGE"]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["MAGE"]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["WARLOCK"]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["WARLOCK"]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["WARLOCK"]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["MONK"][1]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["MONK"][1]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["MONK"][1]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["MONK"][2]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["MONK"][2]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["MONK"][2]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["MONK"][3]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["MONK"][3]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["MONK"][3]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["MONK"][4]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["MONK"][4]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["MONK"][4]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["MONK"][5]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["MONK"][5]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["MONK"][5]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["MONK"][6]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["MONK"][6]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["MONK"][6]["b"] = classColor.b
E.db["unitframe"]["colors"]["power"]["MANA"]["b"] = 161 / 255
E.db["unitframe"]["colors"]["power"]["MANA"]["g"] = 115 / 255
E.db["unitframe"]["colors"]["power"]["MANA"]["r"] = 79 / 255
E.db["unitframe"]["colors"]["power"]["FURY"]["r"] = 227 / 255
E.db["unitframe"]["colors"]["power"]["FURY"]["g"] = 126 / 255
E.db["unitframe"]["colors"]["power"]["FURY"]["b"] = 39 / 255
E.db["unitframe"]["colors"]["power"]["FOCUS"]["b"] = 69 / 255
E.db["unitframe"]["colors"]["power"]["FOCUS"]["g"] = 110 / 255
E.db["unitframe"]["colors"]["power"]["FOCUS"]["r"] = 181 / 255
E.db["unitframe"]["colors"]["power"]["RUNIC_POWER"]["r"] = 0 / 255
E.db["unitframe"]["colors"]["power"]["RUNIC_POWER"]["g"] = 209 / 255
E.db["unitframe"]["colors"]["power"]["RUNIC_POWER"]["b"] = 255 / 255
E.db["unitframe"]["colors"]["power"]["ENERGY"]["b"] = 89 / 255
E.db["unitframe"]["colors"]["power"]["ENERGY"]["g"] = 161 / 255
E.db["unitframe"]["colors"]["power"]["ENERGY"]["r"] = 166 / 255
E.db["unitframe"]["colors"]["power"]["MAELSTROM"]["r"] = 0 / 255
E.db["unitframe"]["colors"]["power"]["MAELSTROM"]["g"] = 128 / 255
E.db["unitframe"]["colors"]["power"]["MAELSTROM"]["b"] = 255 / 255
E.db["unitframe"]["colors"]["power"]["PAIN"]["r"] = 225 / 255
E.db["unitframe"]["colors"]["power"]["PAIN"]["g"] = 225 / 255
E.db["unitframe"]["colors"]["power"]["PAIN"]["b"] = 225 / 255
E.db["unitframe"]["colors"]["power"]["LUNAR_POWER"]["b"] = 31 / 255
E.db["unitframe"]["colors"]["power"]["LUNAR_POWER"]["g"] = 219 / 255
E.db["unitframe"]["colors"]["power"]["LUNAR_POWER"]["r"] = 230 / 255
E.db["unitframe"]["colors"]["power"]["INSANITY"]["b"] = 176 / 255
E.db["unitframe"]["colors"]["power"]["INSANITY"]["g"] = 36 / 255
E.db["unitframe"]["colors"]["power"]["INSANITY"]["r"] = 140 / 255
E.db["unitframe"]["colors"]["power"]["RAGE"]["b"] = 64 / 255
E.db["unitframe"]["colors"]["power"]["RAGE"]["g"] = 64 / 255
E.db["unitframe"]["colors"]["power"]["RAGE"]["r"] = 199 / 255
E.db["unitframe"]["colors"]["frameGlow"]["targetGlow"]["enable"] = false
E.db["unitframe"]["colors"]["frameGlow"]["mouseoverGlow"]["enable"] = false
E.db["unitframe"]["colors"]["frameGlow"]["mouseoverGlow"]["texture"] = "GennUI Melli"
E.db["unitframe"]["colors"]["transparentAurabars"] = true
E.db["unitframe"]["colors"]["auraBarDebuff"]["r"] = 79 / 255
E.db["unitframe"]["colors"]["auraBarDebuff"]["g"] = 79 / 255
E.db["unitframe"]["colors"]["auraBarDebuff"]["b"] = 79 / 255
E.db["unitframe"]["colors"]["health"]["r"] = 30 / 255
E.db["unitframe"]["colors"]["health"]["g"] = 30 / 255
E.db["unitframe"]["colors"]["health"]["b"] = 30 / 255
E.db["unitframe"]["colors"]["health_backdrop"]["r"] = 30 / 255
E.db["unitframe"]["colors"]["health_backdrop"]["g"] = 30 / 255
E.db["unitframe"]["colors"]["health_backdrop"]["b"] = 30 / 255
E.db["unitframe"]["colors"]["castColor"]["r"] = 0 / 255
E.db["unitframe"]["colors"]["castColor"]["g"] = 128 / 255
E.db["unitframe"]["colors"]["castColor"]["b"] = 255 / 255
E.db["unitframe"]["colors"]["castNoInterrupt"]["r"] = 200 / 255
E.db["unitframe"]["colors"]["castNoInterrupt"]["g"] = 20 / 255
E.db["unitframe"]["colors"]["castNoInterrupt"]["b"] = 20 / 255
E.db["unitframe"]["colors"]["castbar_backdrop"]["r"] = 30 / 255
E.db["unitframe"]["colors"]["castbar_backdrop"]["g"] = 30 / 255
E.db["unitframe"]["colors"]["castbar_backdrop"]["b"] = 30 / 255
E.db["unitframe"]["statusbar"] = "GennUI Melli"
E.db["unitframe"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["fontSize"] = 12
E.db["unitframe"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["smoothbars"] = true
E.db["unitframe"]["smartRaidFilter"] = false
E.db["unitframe"]["cooldown"]["fonts"]["enable"] = true
E.db["unitframe"]["cooldown"]["fonts"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["cooldown"]["fonts"]["fontSize"] = 18
E.db["unitframe"]["cooldown"]["override"] = false

---> UF Custom Texts
E.db["unitframe"]["units"]["player"]["customTexts"] = E.db["unitframe"]["units"]["player"]["customTexts"] or {}
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"] = {}
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"] = {}
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"] = {}
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"] = {}
E.db["unitframe"]["units"]["target"]["customTexts"] = E.db["unitframe"]["units"]["target"]["customTexts"] or {}
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"] = {}
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"] = {}
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"] = {}
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"] = {}
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"] = {}	
E.db["unitframe"]["units"]["boss"]["customTexts"] = E.db["unitframe"]["units"]["boss"]["customTexts"] or {}
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"] = {}
E.db["unitframe"]["units"]["arena"]["customTexts"] = E.db["unitframe"]["units"]["arena"]["customTexts"] or {}
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"] = {}
E.db["unitframe"]["units"]["party"]["customTexts"] = E.db["unitframe"]["units"]["party"]["customTexts"] or {}
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"] = {}
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"] = {}

---> UF Player
E.db["unitframe"]["units"]["player"]["debuffs"]["sizeOverride"] = 26
E.db["unitframe"]["units"]["player"]["debuffs"]["spacing"] = 0
E.db["unitframe"]["units"]["player"]["debuffs"]["enable"] = false
E.db["unitframe"]["units"]["player"]["debuffs"]["perrow"] = 4
E.db["unitframe"]["units"]["player"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["player"]["debuffs"]["yOffset"] = 16
E.db["unitframe"]["units"]["player"]["classbar"]["detachFromFrame"] = true
E.db["unitframe"]["units"]["player"]["classbar"]["fill"] = "spaced"
E.db["unitframe"]["units"]["player"]["classbar"]["detachedWidth"] = 180
E.db["unitframe"]["units"]["player"]["classbar"]["height"] = 4
E.db["unitframe"]["units"]["player"]["classbar"]["additionalPowerText"] = false
E.db["unitframe"]["units"]["player"]["classbar"]["autoHide"] = true
E.db["unitframe"]["units"]["player"]["CombatIcon"]["color"]["b"] = 0.22745098039216
E.db["unitframe"]["units"]["player"]["CombatIcon"]["color"]["g"] = 0.11764705882353
E.db["unitframe"]["units"]["player"]["CombatIcon"]["color"]["r"] = 0.76862745098039
E.db["unitframe"]["units"]["player"]["CombatIcon"]["size"] = 28
E.db["unitframe"]["units"]["player"]["aurabar"]["enable"] = false
E.db["unitframe"]["units"]["player"]["RestIcon"]["yOffset"] = 0
E.db["unitframe"]["units"]["player"]["RestIcon"]["xOffset"] = 0
E.db["unitframe"]["units"]["player"]["RestIcon"]["size"] = 18
E.db["unitframe"]["units"]["player"]["RestIcon"]["texture"] = "RESTING1"
E.db["unitframe"]["units"]["player"]["castbar"]["iconXOffset"] = -2
E.db["unitframe"]["units"]["player"]["castbar"]["width"] = 220
E.db["unitframe"]["units"]["player"]["castbar"]["iconAttachedTo"] = "Castbar"
E.db["unitframe"]["units"]["player"]["castbar"]["iconSize"] = 28
E.db["unitframe"]["units"]["player"]["castbar"]["iconAttached"] = false
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["enable"] = true
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["text_format"] = "|cff00d1ff[gnuihmana]"
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["yOffset"] = -5
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["xOffset"] = 3
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["size"] = 10
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["enable"] = true
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["text_format"] = "[name:long]"
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["yOffset"] = 22
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["justifyH"] = "LEFT"
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["xOffset"] = -2
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["size"] = 16
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["enable"] = true
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["text_format"] = "[health:current]"
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["yOffset"] = -18
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["xOffset"] = 2
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["size"] = 12
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["enable"] = true
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["text_format"] = "[powercolor][power:current]"
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["yOffset"] = -18
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["justifyH"] = "LEFT"
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["xOffset"] = 2
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["size"] = 12
E.db["unitframe"]["units"]["player"]["width"] = 220
E.db["unitframe"]["units"]["player"]["power"]["height"] = 4
E.db["unitframe"]["units"]["player"]["power"]["enable"] = true
E.db["unitframe"]["units"]["player"]["power"]["text_format"] = ""
E.db["unitframe"]["units"]["player"]["power"]["width"] = "inset"
E.db["unitframe"]["units"]["player"]["health"]["text_format"] = ""
E.db["unitframe"]["units"]["player"]["height"] = 25
E.db["unitframe"]["units"]["player"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["player"]["buffs"]["enable"] = true
E.db["unitframe"]["units"]["player"]["buffs"]["yOffset"] = 16
E.db["unitframe"]["units"]["player"]["buffs"]["anchorPoint"] = "TOPRIGHT"
E.db["unitframe"]["units"]["player"]["buffs"]["spacing"] = 0
E.db["unitframe"]["units"]["player"]["buffs"]["attachTo"] = "FRAME"
E.db["unitframe"]["units"]["player"]["buffs"]["priority"] = "Blacklist,blockNoDuration,Personal,PlayerBuffs,Whitelist,nonPersonal"
E.db["unitframe"]["units"]["player"]["buffs"]["sizeOverride"] = 26
E.db["unitframe"]["units"]["player"]["buffs"]["perrow"] = 4
E.db["unitframe"]["units"]["player"]["raidicon"]["attachTo"] = "CENTER"
E.db["unitframe"]["units"]["player"]["raidicon"]["yOffset"] = 0
E.db["unitframe"]["units"]["player"]["pvp"]["text_format"] = ""
E.db["unitframe"]["units"]["player"]["threatStyle"] = "NONE"

---> UF Target
E.db["unitframe"]["units"]["target"]["debuffs"]["attachTo"] = "FRAME"
E.db["unitframe"]["units"]["target"]["debuffs"]["sizeOverride"] = 26
E.db["unitframe"]["units"]["target"]["debuffs"]["maxDuration"] = 0
E.db["unitframe"]["units"]["target"]["debuffs"]["spacing"] = 0
E.db["unitframe"]["units"]["target"]["debuffs"]["enable"] = true
E.db["unitframe"]["units"]["target"]["debuffs"]["priority"] = "Blacklist,Friendly:Dispellable,CCDebuffs,Personal,RaidDebuffs"
E.db["unitframe"]["units"]["target"]["debuffs"]["perrow"] = 4
E.db["unitframe"]["units"]["target"]["debuffs"]["yOffset"] = 16
E.db["unitframe"]["units"]["target"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["target"]["raidRoleIcons"]["position"] = "TOPRIGHT"
E.db["unitframe"]["units"]["target"]["aurabar"]["height"] = 16
E.db["unitframe"]["units"]["target"]["aurabar"]["priority"] = "Blacklist,Personal,PlayerBuffs,Boss,RaidDebuffs,blockNoDuration"
E.db["unitframe"]["units"]["target"]["aurabar"]["yOffset"] = 2
E.db["unitframe"]["units"]["target"]["castbar"]["iconAttached"] = false
E.db["unitframe"]["units"]["target"]["castbar"]["iconXOffset"] = 2
E.db["unitframe"]["units"]["target"]["castbar"]["width"] = 220
E.db["unitframe"]["units"]["target"]["castbar"]["iconSize"] = 28
E.db["unitframe"]["units"]["target"]["castbar"]["iconPosition"] = "RIGHT"
E.db["unitframe"]["units"]["target"]["castbar"]["iconAttachedTo"] = "Castbar"
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["enable"] = true
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["text_format"] = "[smartlevel] [namecolor][classification]"
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["yOffset"] = 22
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["justifyH"] = "LEFT"
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["xOffset"] = 0
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["size"] = 10
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["enable"] = true
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["text_format"] = "[name:abbrev:long]"
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["yOffset"] = 22
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["xOffset"] = 2
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["size"] = 16
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["enable"] = true
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["text_format"] = "[powercolor][power:current]"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["yOffset"] = -18
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["xOffset"] = 0
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["size"] = 12
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["enable"] = true
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["text_format"] = "[health:current]|[perhp]%"
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["yOffset"] = -18
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["justifyH"] = "LEFT"
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["xOffset"] = 0
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["size"] = 12
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["enable"] = true
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["text_format"] = ""
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["yOffset"] = -4
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["justifyH"] = "LEFT"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["xOffset"] = 1
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["size"] = 10
E.db["unitframe"]["units"]["target"]["name"]["text_format"] = ""
E.db["unitframe"]["units"]["target"]["width"] = 220
E.db["unitframe"]["units"]["target"]["health"]["xOffset"] = 2
E.db["unitframe"]["units"]["target"]["health"]["text_format"] = ""
E.db["unitframe"]["units"]["target"]["power"]["height"] = 4
E.db["unitframe"]["units"]["target"]["power"]["enable"] = true
E.db["unitframe"]["units"]["target"]["power"]["reverseFill"] = true
E.db["unitframe"]["units"]["target"]["power"]["xOffset"] = -2
E.db["unitframe"]["units"]["target"]["power"]["text_format"] = ""
E.db["unitframe"]["units"]["target"]["power"]["width"] = "inset"
E.db["unitframe"]["units"]["target"]["height"] = 25
E.db["unitframe"]["units"]["target"]["buffs"]["anchorPoint"] = "TOPLEFT"
E.db["unitframe"]["units"]["target"]["buffs"]["sizeOverride"] = 26
E.db["unitframe"]["units"]["target"]["buffs"]["spacing"] = 0
E.db["unitframe"]["units"]["target"]["buffs"]["perrow"] = 4
E.db["unitframe"]["units"]["target"]["buffs"]["priority"] = "Blacklist,Dispellable,TurtleBuffs,Personal,nonPersonal,blockNoDuration" 
E.db["unitframe"]["units"]["target"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["target"]["buffs"]["yOffset"] = 16
E.db["unitframe"]["units"]["target"]["fader"]["hover"] = true
E.db["unitframe"]["units"]["target"]["fader"]["combat"] = true
E.db["unitframe"]["units"]["target"]["fader"]["power"] = true
E.db["unitframe"]["units"]["target"]["fader"]["vehicle"] = true
E.db["unitframe"]["units"]["target"]["fader"]["casting"] = true
E.db["unitframe"]["units"]["target"]["fader"]["health"] = true
E.db["unitframe"]["units"]["target"]["fader"]["playertarget"] = true
E.db["unitframe"]["units"]["target"]["raidicon"]["attachTo"] = "CENTER"
E.db["unitframe"]["units"]["target"]["raidicon"]["yOffset"] = 0
E.db["unitframe"]["units"]["target"]["threatStyle"] = "NONE"

---> UF Pet
E.db["unitframe"]["units"]["pet"]["debuffs"]["anchorPoint"] = "BOTTOMLEFT"
E.db["unitframe"]["units"]["pet"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["pet"]["debuffs"]["enable"] = true
E.db["unitframe"]["units"]["pet"]["debuffs"]["sizeOverride"] = 20
E.db["unitframe"]["units"]["pet"]["debuffs"]["perrow"] = 3
E.db["unitframe"]["units"]["pet"]["threatStyle"] = "NONE"
E.db["unitframe"]["units"]["pet"]["power"]["height"] = 4
E.db["unitframe"]["units"]["pet"]["power"]["enable"] = false
E.db["unitframe"]["units"]["pet"]["name"]["text_format"] = "[name:short]"
E.db["unitframe"]["units"]["pet"]["width"] = 100
E.db["unitframe"]["units"]["pet"]["infoPanel"]["height"] = 14
E.db["unitframe"]["units"]["pet"]["buffs"]["anchorPoint"] = "BOTTOMRIGHT"
E.db["unitframe"]["units"]["pet"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["pet"]["buffs"]["enable"] = true
E.db["unitframe"]["units"]["pet"]["buffs"]["sizeOverride"] = 20
E.db["unitframe"]["units"]["pet"]["buffs"]["perrow"] = 2
E.db["unitframe"]["units"]["pet"]["height"] = 25
E.db["unitframe"]["units"]["pet"]["castbar"]["iconAttached"] = false
E.db["unitframe"]["units"]["pet"]["castbar"]["iconXOffset"] = -2
E.db["unitframe"]["units"]["pet"]["castbar"]["enable"] = false
E.db["unitframe"]["units"]["pet"]["castbar"]["iconSize"] = 28
E.db["unitframe"]["units"]["pet"]["castbar"]["iconAttachedTo"] = "Castbar"
E.db["unitframe"]["units"]["pet"]["castbar"]["width"] = 100

---> UF Target's Target
E.db["unitframe"]["units"]["targettarget"]["debuffs"]["attachTo"] = "FRAME"
E.db["unitframe"]["units"]["targettarget"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["targettarget"]["debuffs"]["priority"] = "Blacklist,Boss,RaidDebuffs,Personal,CCDebuffs,Dispellable,Whitelist,nonPersonal"
E.db["unitframe"]["units"]["targettarget"]["debuffs"]["sizeOverride"] = 20
E.db["unitframe"]["units"]["targettarget"]["debuffs"]["perrow"] = 3
E.db["unitframe"]["units"]["targettarget"]["power"]["height"] = 4
E.db["unitframe"]["units"]["targettarget"]["power"]["enable"] = false
E.db["unitframe"]["units"]["targettarget"]["width"] = 100
E.db["unitframe"]["units"]["targettarget"]["height"] = 25
E.db["unitframe"]["units"]["targettarget"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["targettarget"]["buffs"]["enable"] = true
E.db["unitframe"]["units"]["targettarget"]["buffs"]["priority"] = "Blacklist,RaidBuffsElvUI,Personal,PlayerBuffs,Dispellable"
E.db["unitframe"]["units"]["targettarget"]["buffs"]["sizeOverride"] = 20
E.db["unitframe"]["units"]["targettarget"]["buffs"]["perrow"] = 2
E.db["unitframe"]["units"]["targettarget"]["name"]["text_format"] = "[name:short]"
E.db["unitframe"]["units"]["targettarget"]["raidicon"]["yOffset"] = -4

---> UF Focus
E.db["unitframe"]["units"]["focus"]["debuffs"]["anchorPoint"] = "BOTTOMRIGHT"
E.db["unitframe"]["units"]["focus"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["focus"]["debuffs"]["priority"] = "Blacklist,CCDebuffs,Personal,Boss,RaidDebuffs,Dispellable,Whitelist"
E.db["unitframe"]["units"]["focus"]["debuffs"]["sizeOverride"] = 32
E.db["unitframe"]["units"]["focus"]["debuffs"]["perrow"] = 3
E.db["unitframe"]["units"]["focus"]["disableTargetGlow"] = true
E.db["unitframe"]["units"]["focus"]["threatStyle"] = "NONE"
E.db["unitframe"]["units"]["focus"]["power"]["height"] = 4
E.db["unitframe"]["units"]["focus"]["power"]["enable"] = false
E.db["unitframe"]["units"]["focus"]["name"]["text_format"] = "[name:short]"
E.db["unitframe"]["units"]["focus"]["width"] = 100
E.db["unitframe"]["units"]["focus"]["castbar"]["iconXOffset"] = -2
E.db["unitframe"]["units"]["focus"]["castbar"]["iconAttachedTo"] = "Castbar"
E.db["unitframe"]["units"]["focus"]["castbar"]["iconAttached"] = false
E.db["unitframe"]["units"]["focus"]["castbar"]["iconSize"] = 36
E.db["unitframe"]["units"]["focus"]["castbar"]["width"] = 300
E.db["unitframe"]["units"]["focus"]["height"] = 25
E.db["unitframe"]["units"]["focus"]["buffs"]["anchorPoint"] = "LEFT"
E.db["unitframe"]["units"]["focus"]["buffs"]["sizeOverride"] = 26
E.db["unitframe"]["units"]["focus"]["buffs"]["enable"] = true
E.db["unitframe"]["units"]["focus"]["buffs"]["priority"] = "Blacklist,blockNoDuration,TurtleBuffs,Dispellable,PlayerBuffs,Personal,CastByUnit,RaidBuffsElvUI"
E.db["unitframe"]["units"]["focus"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["focus"]["buffs"]["perrow"] = 1
E.db["unitframe"]["units"]["focus"]["raidicon"]["yOffset"] = -4

---> UF Party
E.db["unitframe"]["units"]["party"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["party"]["debuffs"]["xOffset"] = 2
E.db["unitframe"]["units"]["party"]["debuffs"]["priority"] = "Blacklist,CCDebuffs,Dispellable,Boss,RaidDebuffs,Whitelist"
E.db["unitframe"]["units"]["party"]["debuffs"]["sizeOverride"] = 32
E.db["unitframe"]["units"]["party"]["debuffs"]["perrow"] = 3
E.db["unitframe"]["units"]["party"]["debuffs"]["clickThrough"] = true
E.db["unitframe"]["units"]["party"]["rdebuffs"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["party"]["rdebuffs"]["onlyMatchSpellID"] = false
E.db["unitframe"]["units"]["party"]["rdebuffs"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["party"]["rdebuffs"]["stack"]["color"]["b"] = 1
E.db["unitframe"]["units"]["party"]["rdebuffs"]["stack"]["color"]["g"] = 0.9921568627451
E.db["unitframe"]["units"]["party"]["rdebuffs"]["stack"]["color"]["r"] = 0.97254901960784
E.db["unitframe"]["units"]["party"]["raidRoleIcons"]["xOffset"] = -2
E.db["unitframe"]["units"]["party"]["raidRoleIcons"]["yOffset"] = -2
E.db["unitframe"]["units"]["party"]["buffs"]["anchorPoint"] = "RIGHT"
E.db["unitframe"]["units"]["party"]["buffs"]["sizeOverride"] = 26
E.db["unitframe"]["units"]["party"]["buffs"]["enable"] = true
E.db["unitframe"]["units"]["party"]["buffs"]["spacing"] = 0
E.db["unitframe"]["units"]["party"]["buffs"]["xOffset"] = -40
E.db["unitframe"]["units"]["party"]["buffs"]["perrow"] = 1
E.db["unitframe"]["units"]["party"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["party"]["buffs"]["yOffset"] = 12
E.db["unitframe"]["units"]["party"]["buffs"]["clickThrough"] = true
E.db["unitframe"]["units"]["party"]["classbar"]["enable"] = false
E.db["unitframe"]["units"]["party"]["health"]["xOffset"] = 0
E.db["unitframe"]["units"]["party"]["health"]["yOffset"] = -10
E.db["unitframe"]["units"]["party"]["health"]["text_format"] = "[health:current]"
E.db["unitframe"]["units"]["party"]["health"]["position"] = "BOTTOMRIGHT"
E.db["unitframe"]["units"]["party"]["roleIcon"]["xOffset"] = 0
E.db["unitframe"]["units"]["party"]["roleIcon"]["size"] = 12
E.db["unitframe"]["units"]["party"]["roleIcon"]["damager"] = false
E.db["unitframe"]["units"]["party"]["roleIcon"]["yOffset"] = 0
E.db["unitframe"]["units"]["party"]["power"]["enable"] = false
E.db["unitframe"]["units"]["party"]["power"]["text_format"] = ""
E.db["unitframe"]["units"]["party"]["power"]["height"] = 4
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["enable"] = true
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["text_format"] = "[name:medium]"
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["yOffset"] = 14
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["justifyH"] = "LEFT"
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["xOffset"] = 0
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["size"] = 14
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["enable"] = true
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["text_format"] = "|cff00d1ff[gnuihmana]"
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["yOffset"] = -16
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["justifyH"] = "LEFT"
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["xOffset"] = -2
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["size"] = 10
E.db["unitframe"]["units"]["party"]["disableMouseoverGlow"] = true
E.db["unitframe"]["units"]["party"]["width"] = 160
E.db["unitframe"]["units"]["party"]["name"]["text_format"] = ""
E.db["unitframe"]["units"]["party"]["height"] = 25
E.db["unitframe"]["units"]["party"]["verticalSpacing"] = 25
E.db["unitframe"]["units"]["party"]["petsGroup"]["anchorPoint"] = "BOTTOMRIGHT"
E.db["unitframe"]["units"]["party"]["petsGroup"]["name"]["text_format"] = ""
E.db["unitframe"]["units"]["party"]["petsGroup"]["xOffset"] = 0
E.db["unitframe"]["units"]["party"]["petsGroup"]["enable"] = true
E.db["unitframe"]["units"]["party"]["petsGroup"]["height"] = 10
E.db["unitframe"]["units"]["party"]["petsGroup"]["width"] = 100
E.db["unitframe"]["units"]["party"]["raidicon"]["yOffset"] = 0
E.db["unitframe"]["units"]["party"]["threatStyle"] = "NONE"
E.db["unitframe"]["units"]["party"]["phaseIndicator"]["enable"] = false

---> UF Raid
E.db["unitframe"]["units"]["raid"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["raid"]["rdebuffs"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["raid"]["rdebuffs"]["onlyMatchSpellID"] = false
E.db["unitframe"]["units"]["raid"]["rdebuffs"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["raid"]["rdebuffs"]["size"] = 22
E.db["unitframe"]["units"]["raid"]["rdebuffs"]["duration"]["color"]["r"] = 0.96470588235294
E.db["unitframe"]["units"]["raid"]["rdebuffs"]["duration"]["color"]["g"] = 0.97647058823529
E.db["unitframe"]["units"]["raid"]["rdebuffs"]["duration"]["color"]["b"] = 1
E.db["unitframe"]["units"]["raid"]["rdebuffs"]["stack"]["xOffset"] = 2
E.db["unitframe"]["units"]["raid"]["rdebuffs"]["yOffset"] = 4
E.db["unitframe"]["units"]["raid"]["classbar"]["enable"] = false
E.db["unitframe"]["units"]["raid"]["roleIcon"]["xOffset"] = 2
E.db["unitframe"]["units"]["raid"]["roleIcon"]["size"] = 14
E.db["unitframe"]["units"]["raid"]["roleIcon"]["damager"] = false
E.db["unitframe"]["units"]["raid"]["roleIcon"]["yOffset"] = -2
E.db["unitframe"]["units"]["raid"]["power"]["enable"] = false
E.db["unitframe"]["units"]["raid"]["disableMouseoverGlow"] = true
E.db["unitframe"]["units"]["raid"]["width"] = 55
E.db["unitframe"]["units"]["raid"]["name"]["text_format"] = "[name:veryshort]"
E.db["unitframe"]["units"]["raid"]["health"]["text_format"] = ""
E.db["unitframe"]["units"]["raid"]["height"] = 25
E.db["unitframe"]["units"]["raid"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["raid"]["threatStyle"] = "NONE"
E.db["unitframe"]["units"]["raid"]["phaseIndicator"]["enable"] = false

---> UF Raid40
E.db["unitframe"]["units"]["raid40"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["onlyMatchSpellID"] = false
E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["enable"] = true
E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["stack"]["xOffset"] = 2
E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["size"] = 18
E.db["unitframe"]["units"]["raid40"]["classbar"]["enable"] = false
E.db["unitframe"]["units"]["raid40"]["roleIcon"]["size"] = 14
E.db["unitframe"]["units"]["raid40"]["roleIcon"]["xOffset"] = 2
E.db["unitframe"]["units"]["raid40"]["roleIcon"]["enable"] = true
E.db["unitframe"]["units"]["raid40"]["roleIcon"]["damager"] = false
E.db["unitframe"]["units"]["raid40"]["roleIcon"]["yOffset"] = -2
E.db["unitframe"]["units"]["raid40"]["health"]["text_format"] = ""
E.db["unitframe"]["units"]["raid40"]["disableMouseoverGlow"] = true
E.db["unitframe"]["units"]["raid40"]["width"] = 55
E.db["unitframe"]["units"]["raid40"]["numGroups"] = 5
E.db["unitframe"]["units"]["raid40"]["name"]["text_format"] = "[name:veryshort]"
E.db["unitframe"]["units"]["raid40"]["height"] = 18
E.db["unitframe"]["units"]["raid40"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["raid40"]["threatStyle"] = "NONE"
E.db["unitframe"]["units"]["raid40"]["phaseIndicator"]["enable"] = false

---> UF Arena
E.db["unitframe"]["units"]["arena"]["enable"] = true
E.db["unitframe"]["units"]["arena"]["growthDirection"] = "UP"
E.db["unitframe"]["units"]["arena"]["debuffs"]["sizeOverride"] = 28
E.db["unitframe"]["units"]["arena"]["debuffs"]["xOffset"] = -2
E.db["unitframe"]["units"]["arena"]["debuffs"]["priority"] = "Blacklist,blockNoDuration,CCDebuffs,Personal,Whitelist"
E.db["unitframe"]["units"]["arena"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["arena"]["debuffs"]["yOffset"] = 0
E.db["unitframe"]["units"]["arena"]["disableTargetGlow"] = true
E.db["unitframe"]["units"]["arena"]["power"]["position"] = "BOTTOMLEFT"
E.db["unitframe"]["units"]["arena"]["power"]["xOffset"] = 0
E.db["unitframe"]["units"]["arena"]["power"]["height"] = 4
E.db["unitframe"]["units"]["arena"]["power"]["text_format"] = ""
E.db["unitframe"]["units"]["arena"]["power"]["yOffset"] = -4
E.db["unitframe"]["units"]["arena"]["power"]["reverseFill"] = true
E.db["unitframe"]["units"]["arena"]["power"]["width"] = "inset"
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["enable"] = true
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["text_format"] = "[name:medium]"
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["yOffset"] = 12
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["xOffset"] = 2
E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["size"] = 14
E.db["unitframe"]["units"]["arena"]["pvpTrinket"]["size"] = 28
E.db["unitframe"]["units"]["arena"]["width"] = 160
E.db["unitframe"]["units"]["arena"]["castbar"]["iconAttached"] = false
E.db["unitframe"]["units"]["arena"]["castbar"]["iconPosition"] = "RIGHT"
E.db["unitframe"]["units"]["arena"]["castbar"]["width"] = 160
E.db["unitframe"]["units"]["arena"]["castbar"]["iconSize"] = 28
E.db["unitframe"]["units"]["arena"]["castbar"]["iconXOffset"] = 2
E.db["unitframe"]["units"]["arena"]["castbar"]["height"] = 10
E.db["unitframe"]["units"]["arena"]["health"]["yOffset"] = -10
E.db["unitframe"]["units"]["arena"]["health"]["text_format"] = "[health:current]"
E.db["unitframe"]["units"]["arena"]["health"]["position"] = "BOTTOMLEFT"
E.db["unitframe"]["units"]["arena"]["height"] = 25
E.db["unitframe"]["units"]["arena"]["buffs"]["sizeOverride"] = 26
E.db["unitframe"]["units"]["arena"]["buffs"]["perrow"] = 1
E.db["unitframe"]["units"]["arena"]["buffs"]["xOffset"] = 40
E.db["unitframe"]["units"]["arena"]["buffs"]["priority"] = "Blacklist,TurtleBuffs,Dispellable"
E.db["unitframe"]["units"]["arena"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["arena"]["buffs"]["yOffset"] = 10
E.db["unitframe"]["units"]["arena"]["name"]["xOffset"] = 2
E.db["unitframe"]["units"]["arena"]["name"]["yOffset"] = 10
E.db["unitframe"]["units"]["arena"]["name"]["text_format"] = ""
E.db["unitframe"]["units"]["arena"]["name"]["position"] = "RIGHT"

---> UF Boss
E.db["unitframe"]["units"]["boss"]["growthDirection"] = "UP"
E.db["unitframe"]["units"]["boss"]["debuffs"]["maxDuration"] = 300
E.db["unitframe"]["units"]["boss"]["debuffs"]["sizeOverride"] = 28
E.db["unitframe"]["units"]["boss"]["debuffs"]["desaturate"] = false
E.db["unitframe"]["units"]["boss"]["debuffs"]["xOffset"] = -2
E.db["unitframe"]["units"]["boss"]["debuffs"]["priority"] = "Blacklist,Boss,CCDebuffs,Personal,RaidDebuffs,CastByUnit,Whitelist"
E.db["unitframe"]["units"]["boss"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["boss"]["debuffs"]["yOffset"] = 0
E.db["unitframe"]["units"]["boss"]["castbar"]["iconAttached"] = false
E.db["unitframe"]["units"]["boss"]["castbar"]["iconXOffset"] = 2
E.db["unitframe"]["units"]["boss"]["castbar"]["width"] = 160
E.db["unitframe"]["units"]["boss"]["castbar"]["iconSize"] = 28
E.db["unitframe"]["units"]["boss"]["castbar"]["iconPosition"] = "RIGHT"
E.db["unitframe"]["units"]["boss"]["castbar"]["height"] = 10
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["enable"] = true
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["text_format"] = "[name:abbrev:medium]"
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["yOffset"] = 12
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["xOffset"] = 2
E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["size"] = 14
E.db["unitframe"]["units"]["boss"]["disableMouseoverGlow"] = true
E.db["unitframe"]["units"]["boss"]["width"] = 160
E.db["unitframe"]["units"]["boss"]["infoPanel"]["height"] = 17
E.db["unitframe"]["units"]["boss"]["power"]["position"] = "BOTTOMRIGHT"
E.db["unitframe"]["units"]["boss"]["power"]["xOffset"] = 4
E.db["unitframe"]["units"]["boss"]["power"]["height"] = 4
E.db["unitframe"]["units"]["boss"]["power"]["text_format"] = ""
E.db["unitframe"]["units"]["boss"]["power"]["yOffset"] = -16
E.db["unitframe"]["units"]["boss"]["power"]["reverseFill"] = true
E.db["unitframe"]["units"]["boss"]["power"]["width"] = "inset"
E.db["unitframe"]["units"]["boss"]["name"]["xOffset"] = 2
E.db["unitframe"]["units"]["boss"]["name"]["text_format"] = ""
E.db["unitframe"]["units"]["boss"]["name"]["yOffset"] = 10
E.db["unitframe"]["units"]["boss"]["height"] = 25
E.db["unitframe"]["units"]["boss"]["buffs"]["maxDuration"] = 300
E.db["unitframe"]["units"]["boss"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["boss"]["buffs"]["xOffset"] = 40
E.db["unitframe"]["units"]["boss"]["buffs"]["perrow"] = 1
E.db["unitframe"]["units"]["boss"]["buffs"]["sizeOverride"] = 26
E.db["unitframe"]["units"]["boss"]["buffs"]["yOffset"] = 10
E.db["unitframe"]["units"]["boss"]["health"]["yOffset"] = -10
E.db["unitframe"]["units"]["boss"]["health"]["text_format"] = "[health:current]|[perhp]%"
E.db["unitframe"]["units"]["boss"]["health"]["position"] = "BOTTOMLEFT"

---> UF Tank
E.db["unitframe"]["units"]["tank"]["targetsGroup"]["height"] = 18
E.db["unitframe"]["units"]["tank"]["targetsGroup"]["name"]["text_format"] = "[name:short]"
E.db["unitframe"]["units"]["tank"]["targetsGroup"]["width"] = 100
E.db["unitframe"]["units"]["tank"]["rdebuffs"]["font"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["tank"]["rdebuffs"]["onlyMatchSpellID"] = false
E.db["unitframe"]["units"]["tank"]["rdebuffs"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["tank"]["rdebuffs"]["stack"]["color"]["b"] = 0.9921568627451
E.db["unitframe"]["units"]["tank"]["rdebuffs"]["stack"]["color"]["g"] = 1
E.db["unitframe"]["units"]["tank"]["rdebuffs"]["stack"]["color"]["r"] = 0.97254901960784
E.db["unitframe"]["units"]["tank"]["rdebuffs"]["size"] = 22
E.db["unitframe"]["units"]["tank"]["disableMouseoverGlow"] = true
E.db["unitframe"]["units"]["tank"]["width"] = 100
E.db["unitframe"]["units"]["tank"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["tank"]["name"]["text_format"] = "[name:short]"
E.db["unitframe"]["units"]["tank"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["tank"]["height"] = 25
E.db["unitframe"]["units"]["tank"]["threatStyle"] = "NONE"
E.db["unitframe"]["units"]["tank"]["buffIndicator"]["enable"] = false

---> UF Assist
E.db["unitframe"]["units"]["assist"]["targetsGroup"]["height"] = 18
E.db["unitframe"]["units"]["assist"]["targetsGroup"]["name"]["text_format"] = "[name:short]"
E.db["unitframe"]["units"]["assist"]["targetsGroup"]["width"] = 100
E.db["unitframe"]["units"]["assist"]["rdebuffs"]["onlyMatchSpellID"] = false
E.db["unitframe"]["units"]["assist"]["rdebuffs"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["assist"]["rdebuffs"]["size"] = 22
E.db["unitframe"]["units"]["assist"]["disableMouseoverGlow"] = true
E.db["unitframe"]["units"]["assist"]["width"] = 100
E.db["unitframe"]["units"]["assist"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["assist"]["name"]["text_format"] = "[name:short]"
E.db["unitframe"]["units"]["assist"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["unitframe"]["units"]["assist"]["height"] = 25
E.db["unitframe"]["units"]["assist"]["threatStyle"] = "NONE"
E.db["unitframe"]["units"]["assist"]["buffIndicator"]["enable"] = false

-- DataTexts
E.db["datatexts"]["fontSize"] = 11
E.db["datatexts"]["panels"]["MinimapPanel"][1] = "Guild"
E.db["datatexts"]["panels"]["MinimapPanel"][2] = "Friends"
E.db["datatexts"]["panels"]["MinimapPanel"]["border"] = false
E.db["datatexts"]["panels"]["MinimapPanel"]["backdrop"] = false
E.db["datatexts"]["panels"]["RightChatDataPanel"][1] = ""
E.db["datatexts"]["panels"]["RightChatDataPanel"]["backdrop"] = false
E.db["datatexts"]["panels"]["RightChatDataPanel"]["border"] = false
E.db["datatexts"]["panels"]["LeftChatDataPanel"][3] = "System"
E.db["datatexts"]["panels"]["LeftChatDataPanel"]["backdrop"] = false
E.db["datatexts"]["panels"]["LeftChatDataPanel"]["border"] = false
E.db["datatexts"]["font"] = "Century Gothic Bold"
E.db["datatexts"]["fontOutline"] = "OUTLINE"
E.db["datatexts"]["localtime"] = false
E.db["datatexts"]["battleground"] = false

-- ActionBars
E.db["actionbar"]["bar3"]["buttonspacing"] = 1
E.db["actionbar"]["bar3"]["buttonsize"] = 28
E.db["actionbar"]["bar3"]["buttons"] = 12
E.db["actionbar"]["bar6"]["buttonspacing"] = 1
E.db["actionbar"]["bar10"]["buttonspacing"] = 1
E.db["actionbar"]["bar8"]["buttonspacing"] = 1
E.db["actionbar"]["useRangeColorText"] = true
E.db["actionbar"]["bar9"]["buttonspacing"] = 1
E.db["actionbar"]["microbar"]["enabled"] = true
E.db["actionbar"]["microbar"]["mouseover"] = true
E.db["actionbar"]["microbar"]["buttonSpacing"] = 1
E.db["actionbar"]["microbar"]["buttonSize"] = 18
E.db["actionbar"]["fontOutline"] = "OUTLINE"
E.db["actionbar"]["cooldown"]["override"] = false
E.db["actionbar"]["vehicleExitButton"]["size"] = 28
E.db["actionbar"]["bar1"]["buttonspacing"] = 1
E.db["actionbar"]["fontSize"] = 12
E.db["actionbar"]["bar5"]["buttonspacing"] = 1
E.db["actionbar"]["bar5"]["buttonsize"] = 28
E.db["actionbar"]["bar5"]["buttons"] = 12
E.db["actionbar"]["bar2"]["enabled"] = true
E.db["actionbar"]["bar2"]["buttonspacing"] = 1
E.db["actionbar"]["font"] = "Century Gothic Bold"
E.db["actionbar"]["bar7"]["buttonspacing"] = 1
E.db["actionbar"]["extraActionButton"]["scale"] = 0.75
E.db["actionbar"]["zoneActionButton"]["scale"] = 0.75
E.db["actionbar"]["macrotext"] = true
E.db["actionbar"]["stanceBar"]["buttonspacing"] = 1
E.db["actionbar"]["stanceBar"]["buttonsize"] = 22
E.db["actionbar"]["stanceBar"]["mouseover"] = true
E.db["actionbar"]["barPet"]["buttonspacing"] = 1
E.db["actionbar"]["barPet"]["buttonsize"] = 28
E.db["actionbar"]["barPet"]["backdrop"] = false
E.db["actionbar"]["barPet"]["mouseover"] = true
E.db["actionbar"]["bar4"]["buttonspacing"] = 1
E.db["actionbar"]["bar4"]["backdrop"] = false
E.db["actionbar"]["bar4"]["mouseover"] = true

-- NamePlates
E.private["nameplates"]["enable"] = true
--> NP Colors
E.db["nameplates"]["colors"]["castColor"]["b"] = 255 / 255
E.db["nameplates"]["colors"]["castColor"]["g"] = 128 / 255
E.db["nameplates"]["colors"]["castColor"]["r"] = 0 / 255
E.db["nameplates"]["colors"]["castNoInterruptColor"]["b"] = 30 / 255
E.db["nameplates"]["colors"]["castNoInterruptColor"]["g"] = 30 / 255
E.db["nameplates"]["colors"]["castNoInterruptColor"]["r"] = 30 / 255
E.db["nameplates"]["colors"]["classResources"]["DEATHKNIGHT"]["a"] = 1
E.db["nameplates"]["colors"]["classResources"]["DEATHKNIGHT"]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["DEATHKNIGHT"]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["DEATHKNIGHT"]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["WARLOCK"]["a"] = 1
E.db["nameplates"]["colors"]["classResources"]["WARLOCK"]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["WARLOCK"]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["WARLOCK"]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["PALADIN"]["a"] = 1
E.db["nameplates"]["colors"]["classResources"]["PALADIN"]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["PALADIN"]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["PALADIN"]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["MAGE"]["a"] = 1
E.db["nameplates"]["colors"]["classResources"]["MAGE"]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["MAGE"]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["MAGE"]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][1]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][1]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][1]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][2]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][2]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][2]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][3]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][3]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][3]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][4]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][4]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][4]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][5]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][5]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][5]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][6]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][6]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][6]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["MONK"][1]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["MONK"][1]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["MONK"][1]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["MONK"][2]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["MONK"][2]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["MONK"][2]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["MONK"][3]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["MONK"][3]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["MONK"][3]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["MONK"][4]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["MONK"][4]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["MONK"][4]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["MONK"][5]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["MONK"][5]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["MONK"][5]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["MONK"][6]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["MONK"][6]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["MONK"][6]["b"] = classColor.b

---> NP Units
E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["numAuras"] = 4
E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["priority"] = "Blacklist,CCDebuffs,Personal"
E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["size"] = 28
E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["yOffset"] = 7
E.db["nameplates"]["units"]["ENEMY_NPC"]["questIcon"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["ENEMY_NPC"]["raidTargetIndicator"]["xOffset"] = -2
E.db["nameplates"]["units"]["ENEMY_NPC"]["raidTargetIndicator"]["size"] = 26
E.db["nameplates"]["units"]["ENEMY_NPC"]["eliteIcon"]["xOffset"] = 4
E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["numAuras"] = 1
E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["priority"] = "Blacklist,Dispellable,RaidBuffsElvUI,TurtleBuffs,PlayerBuffs,nonPersonal"
E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["size"] = 28
E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["yOffset"] = 7
E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["height"] = 10
E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["iconSize"] = 32
E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["width"] = 180
E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["yOffset"] = -16
E.db["nameplates"]["units"]["ENEMY_NPC"]["health"]["height"] = 14
E.db["nameplates"]["units"]["ENEMY_NPC"]["health"]["text"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_NPC"]["health"]["text"]["format"] = "[health:current]"
E.db["nameplates"]["units"]["ENEMY_NPC"]["health"]["text"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["ENEMY_NPC"]["name"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["ENEMY_NPC"]["name"]["xOffset"] = -2
E.db["nameplates"]["units"]["ENEMY_NPC"]["name"]["format"] = "[namecolor][name:abbrev:medium]"
E.db["nameplates"]["units"]["ENEMY_NPC"]["name"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_NPC"]["name"]["yOffset"] = -4
E.db["nameplates"]["units"]["ENEMY_NPC"]["level"]["xOffset"] = 4
E.db["nameplates"]["units"]["ENEMY_NPC"]["level"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_NPC"]["level"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["ENEMY_NPC"]["level"]["yOffset"] = -4
E.db["nameplates"]["units"]["TARGET"]["classpower"]["height"] = 6
E.db["nameplates"]["units"]["TARGET"]["classpower"]["width"] = 60
E.db["nameplates"]["units"]["TARGET"]["classpower"]["yOffset"] = -12
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["numAuras"] = 4
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["priority"] = "Blacklist,Boss,Dispellable,CCDebuffs,RaidDebuffs"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["size"] = 28
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["yOffset"] = 7
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["questIcon"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["raidTargetIndicator"]["xOffset"] = -2
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["raidTargetIndicator"]["size"] = 26
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["eliteIcon"]["xOffset"] = 4
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["numAuras"] = 1
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["priority"] = "Blacklist,Personal,TurtleBuffs,blockNoDuration"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["size"] = 28
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["yOffset"] = 7
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["height"] = 10
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["iconSize"] = 32
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["width"] = 180
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["yOffset"] = -16
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["health"]["height"] = 14
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["health"]["text"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["health"]["text"]["format"] = "[health:current]"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["health"]["text"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["name"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["name"]["xOffset"] = -2
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["name"]["format"] = "[namecolor][name:abbrev:medium]"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["name"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["name"]["yOffset"] = -4
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["level"]["xOffset"] = 4
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["level"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["level"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["level"]["yOffset"] = -4
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["numAuras"] = 4
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["priority"] = "Blacklist,Dispellable,CCDebuffs,Personal,Boss,blockNoDuration"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["size"] = 28
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["yOffset"] = 7
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["height"] = 10
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["iconSize"] = 32
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["width"] = 180
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["yOffset"] = -16
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["raidTargetIndicator"]["xOffset"] = -2
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["raidTargetIndicator"]["size"] = 26
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["numAuras"] = 1
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["priority"] = "Blacklist,TurtleBuffs,Personal,blockNoDuration"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["size"] = 28
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["yOffset"] = 7
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["title"]["format"] = "[npctitle]"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["name"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["name"]["xOffset"] = -2
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["name"]["format"] = "[namecolor][name:abbrev:medium]"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["name"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["name"]["yOffset"] = -4
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["level"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["level"]["xOffset"] = 4
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["level"]["format"] = "[difficultycolor][level][shortclassification]"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["level"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["level"]["yOffset"] = -4
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["health"]["height"] = 14
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["health"]["text"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["health"]["text"]["format"] = "[health:current]"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["health"]["text"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["health"]["useClassColor"] = false
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["numAuras"] = 4
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["priority"] = "Blacklist,CCDebuffs,Personal,Boss,RaidDebuffs,blockNoDuration"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["size"] = 28
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["yOffset"] = 7
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["height"] = 10
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["iconSize"] = 32
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["width"] = 180
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["yOffset"] = -16
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["raidTargetIndicator"]["xOffset"] = -2
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["raidTargetIndicator"]["size"] = 26
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["maxDuration"] = 0
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["numAuras"] = 1
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["priority"] = "Blacklist,TurtleBuffs,Dispellable,PlayerBuffs"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["size"] = 28
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["yOffset"] = 7
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["title"]["format"] = "[npctitle]"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["health"]["height"] = 14
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["health"]["text"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["health"]["text"]["format"] = "[health:current]"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["health"]["text"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["xOffset"] = 4
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["format"] = "[difficultycolor][level][shortclassification]"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["yOffset"] = -4
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["name"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["name"]["xOffset"] = -2
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["name"]["format"] = "[name:abbrev:medium]"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["name"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["name"]["yOffset"] = -4
E.db["nameplates"]["units"]["PLAYER"]["debuffs"]["numAuras"] = 4
E.db["nameplates"]["units"]["PLAYER"]["debuffs"]["countFont"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["PLAYER"]["debuffs"]["size"] = 28
E.db["nameplates"]["units"]["PLAYER"]["debuffs"]["yOffset"] = 7
E.db["nameplates"]["units"]["PLAYER"]["power"]["enable"] = false
E.db["nameplates"]["units"]["PLAYER"]["name"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["PLAYER"]["name"]["xOffset"] = -2
E.db["nameplates"]["units"]["PLAYER"]["name"]["enable"] = true
E.db["nameplates"]["units"]["PLAYER"]["name"]["format"] = "[namecolor][name:abbrev:medium]"
E.db["nameplates"]["units"]["PLAYER"]["name"]["fontSize"] = 12
E.db["nameplates"]["units"]["PLAYER"]["name"]["yOffset"] = -4
E.db["nameplates"]["units"]["PLAYER"]["showTitle"] = false
E.db["nameplates"]["units"]["PLAYER"]["raidTargetIndicator"]["xOffset"] = -2
E.db["nameplates"]["units"]["PLAYER"]["raidTargetIndicator"]["size"] = 26
E.db["nameplates"]["units"]["PLAYER"]["buffs"]["maxDuration"] = 0
E.db["nameplates"]["units"]["PLAYER"]["buffs"]["countFont"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["PLAYER"]["buffs"]["numAuras"] = 1
E.db["nameplates"]["units"]["PLAYER"]["buffs"]["size"] = 28
E.db["nameplates"]["units"]["PLAYER"]["buffs"]["yOffset"] = 7
E.db["nameplates"]["units"]["PLAYER"]["health"]["height"] = 14
E.db["nameplates"]["units"]["PLAYER"]["health"]["text"]["fontSize"] = 12
E.db["nameplates"]["units"]["PLAYER"]["health"]["text"]["format"] = "[health:current]"
E.db["nameplates"]["units"]["PLAYER"]["health"]["text"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["PLAYER"]["title"]["format"] = "[npctitle]"
E.db["nameplates"]["units"]["PLAYER"]["castbar"]["fontSize"] = 12
E.db["nameplates"]["units"]["PLAYER"]["castbar"]["height"] = 10
E.db["nameplates"]["units"]["PLAYER"]["castbar"]["iconSize"] = 32
E.db["nameplates"]["units"]["PLAYER"]["castbar"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["PLAYER"]["castbar"]["width"] = 180
E.db["nameplates"]["units"]["PLAYER"]["castbar"]["yOffset"] = -16
E.db["nameplates"]["units"]["PLAYER"]["classpower"]["enable"] = false
E.db["nameplates"]["units"]["PLAYER"]["level"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["units"]["PLAYER"]["level"]["xOffset"] = 4
E.db["nameplates"]["units"]["PLAYER"]["level"]["enable"] = true
E.db["nameplates"]["units"]["PLAYER"]["level"]["format"] = "[difficultycolor][level][shortclassification]"
E.db["nameplates"]["units"]["PLAYER"]["level"]["fontSize"] = 12
E.db["nameplates"]["units"]["PLAYER"]["level"]["yOffset"] = -4

--> NP Filters
E.global["nameplate"]["filters"]["ElvUI_NonTarget"]["actions"]["alpha"] = 70
E.global["nameplate"]["filters"]["ElvUI_NonTarget"]["actions"]["scale"] = 1
E.global["nameplate"]["filters"]["ElvUI_Explosives"]["actions"]["scale"] = 1.1
E.global["nameplate"]["filters"]["ElvUI_Target"]["actions"]["alpha"] = 100
E.global["nameplate"]["filters"]["ElvUI_Target"]["actions"]["scale"] = 1

--> NP General
E.db["nameplates"]["plateSize"]["personalWidth"] = 180
E.db["nameplates"]["plateSize"]["friendlyWidth"] = 180
E.db["nameplates"]["plateSize"]["enemyWidth"] = 180
E.db["nameplates"]["font"] = "Century Gothic Bold"
E.db["nameplates"]["statusbar"] = "GennUI Melli"
E.db["nameplates"]["smoothbars"] = true
E.db["nameplates"]["cooldown"]["override"] = false
E.db["nameplates"]["fadeIn"] = false
E.db["nameplates"]["threat"]["badScale"] = 1
E.db["nameplates"]["threat"]["goodScale"] = 1
E.db["nameplates"]["visibility"]["enemy"]["totems"] = true

-- General
E.db["currentTutorial"] = 1
E.db["hideTutorial"] = true
E.db["general"]["itemLevel"]["itemLevelFont"] = "Century Gothic Bold"
E.db["general"]["interruptAnnounce"] = "SAY"
E.db["general"]["talkingHeadFrameScale"] = 0.71
E.db["general"]["autoRepair"] = "PLAYER"
E.db["general"]["autoTrackReputation"] = true
E.db["general"]["minimap"]["locationFont"] = "Century Gothic Bold"
E.db["general"]["minimap"]["locationText"] = "SHOW"
E.db["general"]["minimap"]["size"] = 150
E.db["general"]["font"] = "Century Gothic Bold"
E.db["general"]["altPowerBar"]["statusBar"] = "GennUI Melli"
E.db["general"]["altPowerBar"]["statusBarColor"]["b"] = classColor.b
E.db["general"]["altPowerBar"]["statusBarColor"]["g"] = classColor.g
E.db["general"]["altPowerBar"]["statusBarColor"]["r"] = classColor.r
E.db["general"]["altPowerBar"]["font"] = "Century Gothic Bold"
E.db["general"]["altPowerBar"]["smoothbars"] = true
E.db["general"]["valuecolor"]["r"] = classColor.r
E.db["general"]["valuecolor"]["g"] = classColor.g
E.db["general"]["valuecolor"]["b"] = classColor.b
E.db["general"]["bottomPanel"] = false
E.db["v11NamePlateReset"] = true
E.db["hideTutorial"] = true
E.db["cooldown"]["fonts"]["enable"] = true
E.db["cooldown"]["fonts"]["font"] = "Century Gothic Bold"

-- Private
E.private["general"]["chatBubbleFontSize"] = 12
E.private["general"]["normTex"] = "GennUI Melli"
E.private["general"]["namefont"] = "Century Gothic Bold"
E.private["general"]["glossTex"] = "GennUI Melli"
E.private["general"]["chatBubbleFont"] = "Century Gothic Bold"
E.private["general"]["dmgfont"] = "Century Gothic Bold"
E.private["general"]["minimap"]["hideClassHallReport"] = true

-- Global
E.global["datatexts"]["settings"]["Friends"]["hideApp"] = true
E.global["datatexts"]["settings"]["Friends"]["hideBSAp"] = true
E.global["datatexts"]["settings"]["Friends"]["hideD3"] = true
E.global["datatexts"]["settings"]["Friends"]["hideHero"] = true
E.global["datatexts"]["settings"]["Friends"]["hidePro"] = true
E.global["datatexts"]["settings"]["Friends"]["hideS1"] = true
E.global["datatexts"]["settings"]["Friends"]["hideS2"] = true
E.global["datatexts"]["settings"]["Friends"]["hideVIPR"] = true
E.global["datatexts"]["settings"]["Friends"]["hideWTCG"] = true
E.global["uiScaleInformed"] = true
E.global["general"]["commandBarSetting"] = "DISABLED"
E.global["general"]["UIScale"] = 0.70

-- Aura Filters
--> Heavy Stagger
E.global.unitframe.aurafilters.Whitelist.spells[124273] = { enable = true, priority = 0 }
E.global.unitframe.aurafilters.Blacklist.spells[124273] = { enable = false, priority = 0 }
--> Challenger's Might
E.global.unitframe.aurafilters.Blacklist.spells[206150] = { enable = true, priority = 0 }
--> Challenger's Burden
E.global.unitframe.aurafilters.Blacklist.spells[206151] = { enable = true, priority = 0 }

-- Shadow & Light Config
if IsAddOnLoaded('ElvUI_SLE') then
E.db["movers"]["RaidMarkerBarAnchor"] = "BOTTOM,ElvUIParent,BOTTOM,-282,200"
E.db["sle"]["databars"]["experience"]["chatfilter"]["enable"] = true
E.db["sle"]["databars"]["honor"]["chatfilter"]["awardStyle"] = "STYLE2"
E.db["sle"]["databars"]["honor"]["chatfilter"]["enable"] = true
E.db["sle"]["databars"]["honor"]["chatfilter"]["style"] = "STYLE3"
E.db["sle"]["databars"]["reputation"]["chatfilter"]["enable"] = true
E.db["sle"]["databars"]["reputation"]["chatfilter"]["style"] = "STYLE2"
E.db["sle"]["databars"]["reputation"]["chatfilter"]["styleDec"] = "STYLE2"
E.db["sle"]["raidmarkers"]["notooltip"] = true
E.db["sle"]["raidmarkers"]["mouseover"] = true
E.db["sle"]["raidmarkers"]["spacing"] = 1
E.db["sle"]["media"]["fonts"]["gossip"]["font"] = "Century Gothic Bold"
E.db["sle"]["media"]["fonts"]["mail"]["font"] = "Century Gothic Bold"
E.db["sle"]["media"]["fonts"]["objective"]["font"] = "Century Gothic Bold"
E.db["sle"]["media"]["fonts"]["objectiveHeader"]["font"] = "Century Gothic Bold"
E.db["sle"]["media"]["fonts"]["pvp"]["font"] = "Century Gothic Bold"
E.db["sle"]["media"]["fonts"]["questFontSuperHuge"]["font"] = "Century Gothic Bold"
E.db["sle"]["media"]["fonts"]["subzone"]["font"] = "Century Gothic Bold"
E.db["sle"]["media"]["fonts"]["zone"]["font"] = "Century Gothic Bold"
E.db["sle"]["armory"]["stats"]["itemLevel"]["outline"] = "OUTLINE"
E.db["sle"]["armory"]["stats"]["itemLevel"]["font"] = "Century Gothic Bold"
E.db["sle"]["armory"]["stats"]["statFonts"]["outline"] = "OUTLINE"
E.db["sle"]["armory"]["stats"]["statFonts"]["font"] = "Century Gothic Bold"
E.db["sle"]["armory"]["stats"]["catFonts"]["outline"] = "OUTLINE"
E.db["sle"]["armory"]["stats"]["catFonts"]["font"] = "Century Gothic Bold"
E.db["sle"]["skins"]["objectiveTracker"]["underlineClass"] = true
E.db["sle"]["skins"]["objectiveTracker"]["classHeader"] = true
E.db["sle"]["raidmanager"]["roles"] = true
E.db["sle"]["minimap"]["coords"]["enable"] = true
E.db["sle"]["minimap"]["coords"]["font"] = "Century Gothic Bold"
E.db["sle"]["minimap"]["coords"]["color"]["r"] = classColor.r
E.db["sle"]["minimap"]["coords"]["color"]["g"] = classColor.g
E.db["sle"]["minimap"]["coords"]["color"]["b"] = classColor.b
E.db["sle"]["minimap"]["coords"]["yOffset"] = -68
E.db["sle"]["minimap"]["coords"]["fontSize"] = 10
E.db["sle"]["quests"]["visibility"]["combat"] = "FULL"
E.db["sle"]["quests"]["visibility"]["enable"] = true
E.db["sle"]["quests"]["autoReward"] = true
E.db["sle"]["dt"]["friends"]["hideBSAp"] = true
E.db["sle"]["dt"]["friends"]["hideApp"] = true
E.db["sle"]["dt"]["friends"]["hide_hintline"] = true
E.db["sle"]["dt"]["friends"]["hide_titleline"] = true
E.db["sle"]["dt"]["guild"]["hide_titleline"] = true
E.db["datatexts"]["panels"]["MinimapPanel"][1] = "S&L Guild"
E.db["datatexts"]["panels"]["MinimapPanel"][2] = "S&L Friends"
E.private["sle"]["skins"]["objectiveTracker"]["color"]["b"] = classColor.b
E.private["sle"]["skins"]["objectiveTracker"]["color"]["g"] = classColor.g
E.private["sle"]["skins"]["objectiveTracker"]["color"]["r"] = classColor.r
E.private["sle"]["skins"]["objectiveTracker"]["class"] = true
E.private["sle"]["skins"]["objectiveTracker"]["texture"] = "GennUI Melli"
end

-- ProjectAzilroka Config
if IsAddOnLoaded('ProjectAzilroka') then
E.db["movers"]["SquareMinimapButtonBarMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-179"
GNUI:LoadPAProfile()
end

-- WindTools Config
if IsAddOnLoaded('ElvUI_WindTools') then
E.db["movers"]["WTRaidMarkersBarAnchor"] = "BOTTOM,ElvUIParent,BOTTOM,-281,220"
E.db["movers"]["WTMinimapButtonBarAnchor"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-182"
E.db["movers"]["WTSwitchButtonBarAnchor"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-134,-277"
E.db["movers"]["WTExtraItemsBar1Mover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-216,257"
E.db["movers"]["WTParagonReputationToastFrameMover"] = "TOP,ElvUIParent,TOP,0,-152"
E.db["WT"]["misc"]["gameBar"]["timeAreaHeight"] = 22
E.db["WT"]["misc"]["gameBar"]["additionalText"]["font"]["name"] = "Century Gothic Bold"
E.db["WT"]["misc"]["gameBar"]["backdrop"] = false
E.db["WT"]["misc"]["gameBar"]["time"]["flash"] = false
E.db["WT"]["misc"]["gameBar"]["mouseOver"] = true
E.db["WT"]["misc"]["gameBar"]["enable"] = true
E.db["WT"]["misc"]["gameBar"]["time"]["font"]["name"] = "Century Gothic Bold"
E.db["WT"]["misc"]["gameBar"]["time"]["font"]["size"] = 22
E.db["WT"]["misc"]["gameBar"]["timeAreaWidth"] = 80
E.db["WT"]["misc"]["gameBar"]["home"]["right"] = "140192"
E.db["WT"]["misc"]["gameBar"]["backdropSpacing"] = 1
E.db["WT"]["misc"]["gameBar"]["buttonSize"] = 22
E.db["WT"]["combat"]["combatAlert"]["font"]["size"] = 22
E.db["WT"]["combat"]["combatAlert"]["enterText"] = "In Combat"
E.db["WT"]["combat"]["combatAlert"]["leaveText"] = "Out of Combat"
E.db["WT"]["combat"]["combatAlert"]["speed"] = 2
E.db["WT"]["combat"]["combatAlert"]["animationSize"] = 0.5
E.db["WT"]["combat"]["raidMarkers"]["spacing"] = 1
E.db["WT"]["combat"]["raidMarkers"]["backdropSpacing"] = 1
E.db["WT"]["combat"]["raidMarkers"]["backdrop"] = false
E.db["WT"]["combat"]["raidMarkers"]["buttonSize"] = 18
E.db["WT"]["item"]["delete"]["enable"] = false
E.db["WT"]["item"]["extraItemsBar"]["bar2"]["enable"] = false
E.db["WT"]["item"]["extraItemsBar"]["bar1"]["include"] = "POTION,FLASK,QUEST"
E.db["WT"]["item"]["extraItemsBar"]["bar1"]["countFont"]["name"] = "Century Gothic Bold"
E.db["WT"]["item"]["extraItemsBar"]["bar1"]["countFont"]["size"] = 11
E.db["WT"]["item"]["extraItemsBar"]["bar1"]["backdropSpacing"] = 1
E.db["WT"]["item"]["extraItemsBar"]["bar1"]["spacing"] = 1
E.db["WT"]["item"]["extraItemsBar"]["bar1"]["buttonHeight"] = 28
E.db["WT"]["item"]["extraItemsBar"]["bar1"]["bindFont"]["name"] = "Century Gothic Bold"
E.db["WT"]["item"]["extraItemsBar"]["bar1"]["bindFont"]["size"] = 11
E.db["WT"]["item"]["extraItemsBar"]["bar1"]["backdrop"] = false
E.db["WT"]["item"]["extraItemsBar"]["bar1"]["buttonWidth"] = 28
E.db["WT"]["item"]["inspect"]["enable"] = false
E.db["WT"]["item"]["inspect"]["equipText"]["size"] = 12
E.db["WT"]["item"]["inspect"]["levelText"]["name"] = "Century Gothic Bold"
E.db["WT"]["item"]["inspect"]["levelText"]["size"] = 14
E.db["WT"]["item"]["inspect"]["statsText"]["size"] = 12
E.db["WT"]["announcement"]["interrupt"]["enable"] = false
E.db["WT"]["announcement"]["interrupt"]["others"]["enable"] = true
E.db["WT"]["announcement"]["interrupt"]["player"]["channel"]["instance"] = "SAY"
E.db["WT"]["announcement"]["interrupt"]["player"]["channel"]["party"] = "SAY"
E.db["WT"]["announcement"]["interrupt"]["player"]["channel"]["solo"] = "EMOTE"
E.db["WT"]["announcement"]["interrupt"]["player"]["channel"]["raid"] = "SAY"
E.db["WT"]["announcement"]["threatTransfer"]["enable"] = false
E.db["WT"]["announcement"]["taunt"]["enable"] = false
E.db["WT"]["announcement"]["thanksForResurrection"]["soulstoneText"] = "%target%, thanks :)"
E.db["WT"]["announcement"]["thanksForResurrection"]["normalText"] = "%target%, thanks :)"
E.db["WT"]["announcement"]["quest"]["weekly"]["enable"] = false
E.db["WT"]["announcement"]["quest"]["daily"]["enable"] = false
E.db["WT"]["announcement"]["quest"]["paused"] = false
E.db["WT"]["announcement"]["quest"]["enable"] = false
E.db["WT"]["announcement"]["quest"]["level"]["enable"] = false
E.db["WT"]["announcement"]["quest"]["suggestedGroup"]["enable"] = false
E.db["WT"]["announcement"]["quest"]["tag"]["enable"] = false
E.db["WT"]["social"]["chatLink"]["enable"] = false
E.db["WT"]["social"]["chatLink"]["compatibile"] = false
E.db["WT"]["social"]["friendList"]["nameFont"]["size"] = 11
E.db["WT"]["social"]["friendList"]["hideMaxLevel"] = false
E.db["WT"]["social"]["friendList"]["infoFont"]["size"] = 11
E.db["WT"]["social"]["chatText"]["removeRealm"] = false
E.db["WT"]["social"]["filter"]["enable"] = false
E.db["WT"]["social"]["chatBar"]["enable"] = false
E.db["WT"]["social"]["smartTab"]["enable"] = false
E.db["WT"]["quest"]["switchButtons"]["enable"] = false
E.db["WT"]["quest"]["turnIn"]["selectReward"] = false
E.db["WT"]["quest"]["turnIn"]["enable"] = false
E.db["WT"]["maps"]["whoClicked"]["font"]["size"] = 12
E.db["WT"]["item"]["fastLoot"]["enable"] = false
E.private["WT"]["maps"]["minimapButtons"]["buttonSize"] = 22
E.private["WT"]["maps"]["minimapButtons"]["backdropSpacing"] = 1
E.private["WT"]["maps"]["minimapButtons"]["backdrop"] = false
E.private["WT"]["maps"]["minimapButtons"]["spacing"] = 1
E.private["WT"]["maps"]["worldMap"]["scale"]["size"] = 1
E.private["WT"]["misc"]["rememberPositions"] = false
E.private["WT"]["combat"]["talentManager"]["enable"] = false
E.private["WT"]["quest"]["objectiveTracker"]["title"]["size"] = 12
E.private["WT"]["quest"]["objectiveTracker"]["titleColor"]["classColor"] = true
E.private["WT"]["quest"]["objectiveTracker"]["header"]["size"] = 12
E.private["WT"]["quest"]["objectiveTracker"]["colorfulPercentage"] = true
E.private["WT"]["quest"]["objectiveTracker"]["percentage"] = false
E.private["WT"]["skins"]["errorMessage"]["size"] = 14
E.private["WT"]["skins"]["ime"]["label"]["name"] = "Century Gothic Bold"
E.private["WT"]["skins"]["ime"]["label"]["size"] = 12
E.private["WT"]["skins"]["shadow"] = false
E.private["WT"]["tooltips"]["progression"]["enable"] = false
E.private["WT"]["tooltips"]["icon"] = false
E.private["WT"]["unitFrames"]["quickFocus"]["enable"] = false
end

-- Update ElvUI
	E:StaggeredUpdateAll(nil, true)
	E:Print(L["|cffc31f3bGennUI |cfffffffflayout has been set"])
	PluginInstallStepComplete.message = "GennUI Layout has been set"
	PluginInstallStepComplete:Show()
end

--[[ Theme Settings ]]--
function GNUI:SetupTheme(theme)
if theme == "dark" then
	E.db["unitframe"]["colors"]["healthclass"] = false
	E.db["unitframe"]["colors"]["powerclass"] = true
	E.db["unitframe"]["colors"]["classbackdrop"] = true
	E.db["unitframe"]["colors"]["customhealthbackdrop"] = false
	E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["text_format"] = "[namecolor][name:long]"
	E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["text_format"] = "[namecolor][power:current]"
	E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["text_format"] = "[namecolor][name:abbrev:long]"
	E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["text_format"] = "[namecolor][power:current]"
	E.db["unitframe"]["units"]["targettarget"]["name"]["text_format"] = "[namecolor][name:short]"
	E.db["unitframe"]["units"]["focus"]["name"]["text_format"] = "[namecolor][name:short]"
	E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["text_format"] = "[namecolor][name:medium]"
	E.db["unitframe"]["units"]["raid"]["name"]["text_format"] = "[namecolor][name:veryshort]"
	E.db["unitframe"]["units"]["raid40"]["name"]["text_format"] = "[namecolor][name:veryshort]"
	E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["text_format"] = "[namecolor][name:medium]"
	E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["text_format"] = "[namecolor][name:abbrev:medium]"
	E.db["unitframe"]["units"]["tank"]["name"]["text_format"] = "[namecolor][name:short]"
	E.db["unitframe"]["units"]["assist"]["name"]["text_format"] = "[namecolor][name:short]"
	elseif theme == "class" then
	E.db["unitframe"]["colors"]["healthclass"] = true
	E.db["unitframe"]["colors"]["powerclass"] = false
	E.db["unitframe"]["colors"]["classbackdrop"] = false
	E.db["unitframe"]["colors"]["customhealthbackdrop"] = true
	E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["text_format"] = "[name:long]"
	E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["text_format"] = "[powercolor][power:current]"
	E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["text_format"] = "[name:abbrev:long]"
	E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["text_format"] = "[powercolor][power:current]"
	E.db["unitframe"]["units"]["targettarget"]["name"]["text_format"] = "[name:short]"
	E.db["unitframe"]["units"]["focus"]["name"]["text_format"] = "[name:short]"
	E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["text_format"] = "[name:medium]"
	E.db["unitframe"]["units"]["raid"]["name"]["text_format"] = "[name:veryshort]"
	E.db["unitframe"]["units"]["raid40"]["name"]["text_format"] = "[name:veryshort]"
	E.db["unitframe"]["units"]["arena"]["customTexts"]["gName"]["text_format"] = "[name:medium]"
	E.db["unitframe"]["units"]["boss"]["customTexts"]["gName"]["text_format"] = "[name:abbrev:medium]"
	E.db["unitframe"]["units"]["tank"]["name"]["text_format"] = "[name:short]"
	E.db["unitframe"]["units"]["assist"]["name"]["text_format"] = "[name:short]"	
end
	
--Update ElvUI
	E:StaggeredUpdateAll(nil, true)
	E:Print(L["|cffc31f3bGennUI |cfffffffftheme has been set"])
	PluginInstallStepComplete.message = "Theme has been set"
	PluginInstallStepComplete:Show()
end

--[[ Addons Profiles ]]--
function GNUI:SetupAddons(addon)
	
	-- AddOnSkins
	if IsAddOnLoaded('AddOnSkins') then
		GNUI:LoadASProfile()
		E:Print(L["'AddOnSkins' profile has been set."])
	end
	
	-- Arena Team Tracker
	if IsAddOnLoaded('ATT') then
		GNUI:LoadATTProfile()
		E:Print(L["'Arena Team Tracker' profile has been set."])
	end
	
	-- BattleGround Enemies
	if IsAddOnLoaded('BattleGroundEnemies') then
		GNUI:LoadBGEProfile()
		E:Print(L["'BattleGroundEnemies' profile has been set."])
	end
	
	-- BigWigs
	if IsAddOnLoaded('BigWigs') then
		GNUI:LoadBWProfile()
		E:Print(L["'BigWigs'"])
	end
	
	-- Capping
	if IsAddOnLoaded('Capping') then
		GNUI:LoadCappingProfile()
		E:Print(L["'Capping' profile has been set."])
	end
	
	-- Deadly Boss Mods
	if IsAddOnLoaded('DBM-Core') then
		GNUI:LoadDBMProfile()
		E:Print(L["'DBM' profile has been set."])
	end
	
	-- Details
	if IsAddOnLoaded('Details') then
		GNUI:LoadDetailsProfile()
		E:Print(L["'Details' profile has been set."])
	end
	
	-- Diminish
	if IsAddOnLoaded('Diminish') then
		GNUI:LoadDiminishProfile()
		E:Print(L["'Diminish' profile has been set."])
	end
	
	-- Gladius
	if IsAddOnLoaded('Gladius') then
		E.db["unitframe"]["units"]["arena"]["enable"] = false
		GNUI:LoadGladiusProfile()
		E:Print(L["'Gladius' profile has been set. Note: ElvUI Arena Frames have been disabled"])
	end
	
	-- GottaGoFast
	if IsAddOnLoaded('GottaGoFast') then
		if E.myclass == 'DEATHKNIGHT' then
		GNUI:LoadGGFDKProfile()
		end
		if E.myclass == 'DEMONHUNTER' then
		GNUI:LoadGGFDHProfile()
		end
		if E.myclass == 'DRUID' then
		GNUI:LoadGGFDruidProfile()
		end
		if E.myclass == 'HUNTER' then
		GNUI:LoadGGFHunterProfile()
		end
		if E.myclass == 'MAGE' then
		GNUI:LoadGGFMageProfile()
		end
		if E.myclass == 'MONK' then
		GNUI:LoadGGFMonkProfile()
		end
		if E.myclass == 'PALADIN' then
		GNUI:LoadGGFPaladinProfile()
		end
		if E.myclass == 'PRIEST' then
		GNUI:LoadGGFPriestProfile()
		end
		if E.myclass == 'ROGUE' then
		GNUI:LoadGGFRogueProfile()
		end
		if E.myclass == 'SHAMAN' then
		GNUI:LoadGGFShamanProfile()
		end
		if E.myclass == 'WARLOCK' then
		GNUI:LoadGGFWarlockProfile()
		end
		if E.myclass == 'WARRIOR' then
		GNUI:LoadGGFWarriorProfile()
		end
		E:Print(L["'GottaGoFast' profile has been set."])
	end
	
	-- Mik's Scrolling Battle Text
	if IsAddOnLoaded('MikScrollingBattleText') then
		GNUI:LoadMSBTProfile()
		E:Print(L["'MSBT' profile has been set."])
	end
	
	-- NamePlate Cooldowns
	if IsAddOnLoaded('NameplateCooldowns') then
		GNUI:LoadNCProfile()
		E:Print(L["'NameplateCooldowns' profile has been set."])
	end
	
	-- OmniCD
	if IsAddOnLoaded('OmniCD') then
		GNUI:LoadOmniCDProfile()
		E:Print(L["'OmniCD' profile has been set."])
	end
	
	-- Plater
	if IsAddOnLoaded('Plater') then
		E.private["nameplates"]["enable"] = false
		GNUI:LoadPlaterProfile()
		E:Print(L["'Plater' profile has been set. Note: ElvUI NamePlates have been disabled"])
	end
	
	-- Skada
	if IsAddOnLoaded('Skada') then
		GNUI:LoadSkadaProfile()
		E:Print(L["'Skada' profile has been set."])
	end
	
	PluginInstallStepComplete.message = "Addons Profiles have been set"
	PluginInstallStepComplete:Show()
end